@@ -21,3 +21,13 @@ class ProfileKinds(ExtendedEnum):
 
     BINARY = "binary"
     REGRESSION = "regression"
+
+
+class ArrowFormatKinds(ExtendedEnum):
+    """ArrowFormatKinds.
+    Return types of an arrow / profiled endpoint
+    """
+
+    DATAFRAME = "dataframe"
+    SERIES = "series"
+    ARRAY = "array"
